# Engineered datasets

[![PyPI release](https://github.com/gperdrizet/engineered_datasets/actions/workflows/publish_pypi.yml/badge.svg?event=push)](https://github.com/gperdrizet/engineered_datasets/actions/workflows/publish_pypi.yml)

Dataset generator for tabular data modeling and prediction projects.
